import { __decorate, __spread, __assign, __extends, __param } from 'tslib';
import { InjectionToken, Input, HostBinding, Component, ViewChild, ViewContainerRef, ElementRef, Renderer2, Optional, Inject, ChangeDetectorRef, ComponentFactoryResolver, ContentChild, TemplateRef, Directive, ContentChildren, Injectable, Pipe, NgModule } from '@angular/core';
import { FormControlName, FormArrayName, FormGroup, ControlContainer, FormGroupDirective, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { Subject, merge } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { CommonModule } from '@angular/common';

var ValidationErrorsConfigObject = new InjectionToken('ValidationErrorsConfigObject');
var FOR_ROOT_OPTIONS_TOKEN = new InjectionToken('forRootOptionToken');
var MESSAGES_PROVIDER = new InjectionToken('MessagesProvider');
var MESSAGES_PIPE_FACTORY_TOKEN = new InjectionToken('MessagePipeFactoryToken');

var InputErrorsComponent = /** @class */ (function () {
    function InputErrorsComponent() {
        this.messages = [];
        this.params = {};
    }
    __decorate([
        Input()
    ], InputErrorsComponent.prototype, "messages", void 0);
    __decorate([
        Input()
    ], InputErrorsComponent.prototype, "params", void 0);
    __decorate([
        Input(), HostBinding('class.is-inner')
    ], InputErrorsComponent.prototype, "innerValidationError", void 0);
    __decorate([
        Input()
    ], InputErrorsComponent.prototype, "control", void 0);
    InputErrorsComponent = __decorate([
        Component({
            // tslint:disable-next-line:component-selector
            selector: 'input-errors',
            template: "\n      <div class=\"error-wrapper\">\n          <span\n              class=\"help-block\"\n              *ngFor=\"let message of messages;\"\n          >{{ message | mapToMessage: params }}</span>\n      </div>\n  ",
            styles: [":host{position:absolute}:host .error-wrapper{position:relative;left:41px;bottom:2px}:host .error-wrapper span{font-size:.8em;color:red;font-weight:500}:host(.is-inner){position:absolute}:host(.is-inner) .error-wrapper{position:relative;left:37px;bottom:20px}:host(.is-inner) .error-wrapper span{font-size:.8em;color:red;font-weight:500}"]
        })
    ], InputErrorsComponent);
    return InputErrorsComponent;
}());

function toScreamingSnakeCase(input) {
    return input.replace(/([a-z])([A-Z])/g, '$1_$2').toUpperCase();
}

function wrapMethod(subject$, name, control) {
    var prevMethod = control[name];
    function wrappedMethod() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        prevMethod.bind(control).apply(void 0, __spread(args));
        subject$.next();
    }
    control[name] = wrappedMethod;
}
function toChangeObservable(control) {
    var touchedChanges$ = new Subject();
    wrapMethod(touchedChanges$, 'markAsTouched', control);
    wrapMethod(touchedChanges$, 'markAsUntouched', control);
    wrapMethod(touchedChanges$, 'markAsDirty', control);
    wrapMethod(touchedChanges$, 'markAsPristine', control);
    var obs = merge(touchedChanges$, control.statusChanges);
    return obs.pipe(debounceTime(100));
}

var FormValidationContainer = /** @class */ (function () {
    function FormValidationContainer(elRef, renderer, messageProvider, cdRef, componentFactoryResolver, validationErrorsConfig) {
        this.elRef = elRef;
        this.renderer = renderer;
        this.messageProvider = messageProvider;
        this.cdRef = cdRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.validationErrorsConfig = validationErrorsConfig;
        this.customErrorMessages = {};
        this.messageParams = {};
        this.validationDisabled = false;
        this.validationContext = validationErrorsConfig.defaultContext;
    }
    FormValidationContainer.prototype.ngAfterContentInit = function () {
        var _this = this;
        this.addErrorComponent();
        this.subscription = toChangeObservable(this.formControl).subscribe(function (value) {
            _this.checkErrors();
            _this.checkSuccess();
            _this.updateErrorComponent();
        });
    };
    FormValidationContainer.prototype.ngOnDestroy = function () {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    };
    FormValidationContainer.prototype.addErrorComponent = function () {
        if (this.errorsContainer && !this.componentRef) {
            this.errorsContainer.clear();
            var componentFactory = this.componentFactoryResolver.resolveComponentFactory(this.validationErrorsConfig.errorComponent);
            this.componentRef = this.errorsContainer.createComponent(componentFactory);
        }
    };
    FormValidationContainer.prototype.updateErrorComponent = function () {
        if (this.componentRef) {
            this.componentRef.instance.innerValidationError = this.innerValidationError;
            this.componentRef.instance.messages = this.messages;
            this.componentRef.instance.params = this.messageParams;
        }
    };
    FormValidationContainer.prototype.checkErrors = function () {
        var _this = this;
        var hasError = (!this.formControl.valid && this.formControl.dirty && this.formControl.touched) && !this.validationDisabled;
        if (hasError && this.el && this.el.nativeElement) {
            this.messages = Object.keys(this.formControl.errors).map(function (error) {
                var fieldName = _this.formControlName;
                var errorKey = toScreamingSnakeCase(fieldName + '') + ".ERRORS." + toScreamingSnakeCase(error);
                if (_this.messageProvider &&
                    _this.messageProvider.instant(_this.validationContext + "." + errorKey) === _this.validationContext + "." + errorKey) {
                    return _this.validationErrorsConfig.defaultContext + ".ERRORS." + toScreamingSnakeCase(error);
                }
                else {
                    return _this.validationContext + "." + errorKey;
                }
            });
            var params = Object.values(this.formControl.errors).reduce(function (a, b) {
                a = __assign(__assign({}, a), b);
                return a;
            }, {});
            this.messageParams = this.messageParams ? __assign(__assign({}, this.messageParams), params) : params;
            if (this.messages && this.messages.length > 0) {
                this.messages = [this.messages[0]];
            }
            try {
                this.renderer.removeClass(this.el.nativeElement, 'is-valid');
            }
            catch (e) {
            }
            this.renderer.addClass(this.el.nativeElement, 'is-invalid');
        }
        this.hasErrors = hasError;
    };
    FormValidationContainer.prototype.checkSuccess = function () {
        var hasSuccess = (this.formControl.valid &&
            this.formControl.dirty && this.formControl.touched) &&
            !this.validationDisabled;
        if (hasSuccess && this.el && this.el.nativeElement) {
            this.messages = [];
            try {
                this.renderer.removeClass(this.el.nativeElement, 'is-invalid');
            }
            catch (e) {
            }
        }
        this.hasSuccess = hasSuccess;
    };
    FormValidationContainer.prototype.setValidationContext = function (context) {
        this.validationContext = context;
    };
    FormValidationContainer.prototype.setInnerValidation = function (innerValidation) {
        this.innerValidationError = innerValidation;
    };
    FormValidationContainer.prototype.clear = function () {
        this.formControl.reset();
        this.formControl.setErrors(null);
        this.renderer.removeClass(this.el.nativeElement, 'is-valid');
        this.renderer.removeClass(this.el.nativeElement, 'is-invalid');
        this.messages = [];
    };
    __decorate([
        Input()
    ], FormValidationContainer.prototype, "customErrorMessages", void 0);
    __decorate([
        Input()
    ], FormValidationContainer.prototype, "messageParams", void 0);
    __decorate([
        Input()
    ], FormValidationContainer.prototype, "validationDisabled", void 0);
    __decorate([
        Input()
    ], FormValidationContainer.prototype, "innerValidationError", void 0);
    __decorate([
        ViewChild('errorsContainer', { read: ViewContainerRef, static: true })
    ], FormValidationContainer.prototype, "errorsContainer", void 0);
    __decorate([
        HostBinding('class.has-error')
    ], FormValidationContainer.prototype, "hasErrors", void 0);
    __decorate([
        HostBinding('class.has-success')
    ], FormValidationContainer.prototype, "hasSuccess", void 0);
    return FormValidationContainer;
}());

var VALIDATION_ERROR_CONFIG = new InjectionToken('validationError.config');

var FormFieldContainerComponent = /** @class */ (function (_super) {
    __extends(FormFieldContainerComponent, _super);
    function FormFieldContainerComponent(
    // tslint:disable-next-line:variable-name
    _elRef, 
    // tslint:disable-next-line:variable-name
    _renderer, 
    // tslint:disable-next-line:variable-name
    _messageProvider, 
    // tslint:disable-next-line:variable-name
    _cdRef, 
    // tslint:disable-next-line:variable-name
    _componentFactoryResolver, 
    // tslint:disable-next-line:variable-name
    _validationErrorsConfig) {
        var _this = _super.call(this, _elRef, _renderer, _messageProvider, _cdRef, _componentFactoryResolver, _validationErrorsConfig) || this;
        _this._elRef = _elRef;
        _this._renderer = _renderer;
        _this._messageProvider = _messageProvider;
        _this._cdRef = _cdRef;
        _this._componentFactoryResolver = _componentFactoryResolver;
        _this._validationErrorsConfig = _validationErrorsConfig;
        return _this;
    }
    Object.defineProperty(FormFieldContainerComponent.prototype, "formControl", {
        get: function () {
            return this._formControl.control;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormFieldContainerComponent.prototype, "formControlName", {
        get: function () {
            return this._formControl.name;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormFieldContainerComponent.prototype, "statusChanges", {
        get: function () {
            return this._formControl.control.statusChanges;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormFieldContainerComponent.prototype, "el", {
        get: function () {
            return this._input;
        },
        enumerable: true,
        configurable: true
    });
    FormFieldContainerComponent.ctorParameters = function () { return [
        { type: ElementRef },
        { type: Renderer2 },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGES_PROVIDER,] }] },
        { type: ChangeDetectorRef },
        { type: ComponentFactoryResolver },
        { type: undefined, decorators: [{ type: Inject, args: [VALIDATION_ERROR_CONFIG,] }] }
    ]; };
    __decorate([
        ContentChild(FormControlName, { static: true })
    ], FormFieldContainerComponent.prototype, "_formControl", void 0);
    __decorate([
        ContentChild(FormControlName, { read: ElementRef, static: true })
    ], FormFieldContainerComponent.prototype, "_input", void 0);
    FormFieldContainerComponent = __decorate([
        Component({
            selector: '[ngxValidationErrorsField], ngx-validation-errors-field, [formFieldContainer], form-field-container',
            template: "\n      <ng-content></ng-content>\n      <ng-template #errorsContainer></ng-template>\n  "
        }),
        __param(2, Optional()), __param(2, Inject(MESSAGES_PROVIDER)),
        __param(5, Inject(VALIDATION_ERROR_CONFIG))
    ], FormFieldContainerComponent);
    return FormFieldContainerComponent;
}(FormValidationContainer));

var FormArrayContainerComponent = /** @class */ (function (_super) {
    __extends(FormArrayContainerComponent, _super);
    function FormArrayContainerComponent(
    // tslint:disable-next-line:variable-name
    _elRef, 
    // tslint:disable-next-line:variable-name
    _renderer, 
    // tslint:disable-next-line:variable-name
    _messageProvider, 
    // tslint:disable-next-line:variable-name
    _cdRef, 
    // tslint:disable-next-line:variable-name
    _componentFactoryResolver, 
    // tslint:disable-next-line:variable-name
    _validationErrorsConfig) {
        var _this = _super.call(this, _elRef, _renderer, _messageProvider, _cdRef, _componentFactoryResolver, _validationErrorsConfig) || this;
        _this._elRef = _elRef;
        _this._renderer = _renderer;
        _this._messageProvider = _messageProvider;
        _this._cdRef = _cdRef;
        _this._componentFactoryResolver = _componentFactoryResolver;
        _this._validationErrorsConfig = _validationErrorsConfig;
        return _this;
    }
    Object.defineProperty(FormArrayContainerComponent.prototype, "formControl", {
        get: function () {
            return this._formControl.control;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormArrayContainerComponent.prototype, "formControlName", {
        get: function () {
            return this._formControl.name;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormArrayContainerComponent.prototype, "statusChanges", {
        get: function () {
            return this._formControl.control.statusChanges;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormArrayContainerComponent.prototype, "el", {
        get: function () {
            return this._el;
        },
        enumerable: true,
        configurable: true
    });
    FormArrayContainerComponent.ctorParameters = function () { return [
        { type: ElementRef },
        { type: Renderer2 },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGES_PROVIDER,] }] },
        { type: ChangeDetectorRef },
        { type: ComponentFactoryResolver },
        { type: undefined, decorators: [{ type: Inject, args: [VALIDATION_ERROR_CONFIG,] }] }
    ]; };
    __decorate([
        ContentChild(FormArrayName, { static: true })
    ], FormArrayContainerComponent.prototype, "_formControl", void 0);
    __decorate([
        ContentChild(FormArrayName, { read: ElementRef, static: true })
    ], FormArrayContainerComponent.prototype, "_el", void 0);
    FormArrayContainerComponent = __decorate([
        Component({
            selector: '[ngxValidationErrorsArray], ngx-validation-errors-array, [formArrayContainer], form-array-container',
            template: "\n      <ng-content></ng-content>\n      <ng-container #errorsContainer></ng-container>\n  "
        }),
        __param(2, Optional()), __param(2, Inject(MESSAGES_PROVIDER)),
        __param(5, Inject(VALIDATION_ERROR_CONFIG))
    ], FormArrayContainerComponent);
    return FormArrayContainerComponent;
}(FormValidationContainer));

var ForFieldErrorsContext = /** @class */ (function () {
    function ForFieldErrorsContext(errors) {
        this.errors = errors;
    }
    return ForFieldErrorsContext;
}());
var FormFieldEmptyContainerDirective = /** @class */ (function () {
    function FormFieldEmptyContainerDirective(renderer, viewContainer, template, 
    // @Optional() form: FormGroupDirective,
    messageProvider, validationErrorsConfig) {
        this.renderer = renderer;
        this.viewContainer = viewContainer;
        this.template = template;
        this.messageProvider = messageProvider;
        this.validationErrorsConfig = validationErrorsConfig;
        this.customErrorMessages = {};
        this.messageParams = {};
        this.validationDisabled = false;
        this.context = { errors: [] };
        this.validationContext = validationErrorsConfig.defaultContext;
        var nodes = this.viewContainer.createEmbeddedView(this.template, this.context);
        this.rootEl = nodes.rootNodes[0];
    }
    FormFieldEmptyContainerDirective.prototype.ngDoCheck = function () {
        var _this = this;
        var hasError = (!this.formControl.valid && this.formControl.touched) && !this.validationDisabled;
        var messages;
        if (hasError) {
            messages = Object.keys(this.formControl.errors).map(function (error) {
                var fieldName = _this.formControlName;
                var errorKey = toScreamingSnakeCase(fieldName) + ".ERRORS." + toScreamingSnakeCase(error);
                if (_this.messageProvider &&
                    _this.messageProvider.instant(_this.validationContext + "." + errorKey) === _this.validationContext + "." + errorKey) {
                    return _this.validationErrorsConfig.defaultContext + ".ERRORS." + toScreamingSnakeCase(error);
                }
                else {
                    return _this.validationContext + "." + errorKey;
                }
            });
            var params = Object.values(this.formControl.errors).reduce(function (a, b) {
                a = __assign(__assign({}, a), b);
                return a;
            }, {});
            this.messageParams = this.messageParams ? __assign(__assign({}, this.messageParams), params) : params;
            if (messages && messages.length > 0) {
                messages = [messages[0]];
            }
        }
        if ((messages && !this.messages) || (!messages && this.messages) || (messages && messages[0] !== this.messages[0])) {
            this.messages = messages;
            this.context.errors = messages;
            if (this.rootEl) {
                if (messages) {
                    this.renderer.addClass(this.rootEl, 'has-error');
                }
                else {
                    this.renderer.removeClass(this.rootEl, 'has-error');
                }
            }
        }
    };
    FormFieldEmptyContainerDirective.prototype.setValidationContext = function (context) {
        this.validationContext = context;
    };
    FormFieldEmptyContainerDirective.prototype.setInnerValidation = function (innerValidation) {
    };
    FormFieldEmptyContainerDirective.prototype.clear = function () {
        this.formControl.reset();
        this.formControl.setErrors(null);
        this.messages = [];
        this.context.errors = undefined;
    };
    Object.defineProperty(FormFieldEmptyContainerDirective.prototype, "formControl", {
        get: function () {
            return this.formControlRef;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FormFieldEmptyContainerDirective.prototype, "formControlName", {
        get: function () {
            var _this = this;
            if (this.formControlRef['_parent'] instanceof FormGroup) {
                var form_1 = this.formControlRef['_parent'];
                var name_1 = Object.keys(form_1.controls).find(function (k) { return form_1.controls[k] === _this.formControlRef; });
                return name_1;
            }
            return 'field';
        },
        enumerable: true,
        configurable: true
    });
    FormFieldEmptyContainerDirective.ctorParameters = function () { return [
        { type: Renderer2 },
        { type: ViewContainerRef },
        { type: TemplateRef },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGES_PROVIDER,] }] },
        { type: undefined, decorators: [{ type: Inject, args: [VALIDATION_ERROR_CONFIG,] }] }
    ]; };
    __decorate([
        Input('ngxValidationErrors')
    ], FormFieldEmptyContainerDirective.prototype, "formControlRef", void 0);
    __decorate([
        Input()
    ], FormFieldEmptyContainerDirective.prototype, "customErrorMessages", void 0);
    __decorate([
        Input()
    ], FormFieldEmptyContainerDirective.prototype, "messageParams", void 0);
    __decorate([
        Input()
    ], FormFieldEmptyContainerDirective.prototype, "validationDisabled", void 0);
    FormFieldEmptyContainerDirective = __decorate([
        Directive({
            selector: '[ngxValidationErrors]',
            providers: [
                {
                    provide: ControlContainer,
                    useExisting: FormGroupDirective
                }
            ]
        }),
        __param(3, Optional()), __param(3, Inject(MESSAGES_PROVIDER)),
        __param(4, Inject(VALIDATION_ERROR_CONFIG))
    ], FormFieldEmptyContainerDirective);
    return FormFieldEmptyContainerDirective;
}());

var ValidationContextComponent = /** @class */ (function () {
    function ValidationContextComponent(cdRef) {
        this.cdRef = cdRef;
    }
    ValidationContextComponent.prototype.ngAfterContentInit = function () {
        var _this = this;
        if (this.fieldValidators) {
            this.fieldValidators.forEach(function (i) {
                i.setValidationContext(_this.validationContext);
                i.setInnerValidation(_this.innerValidationError);
            });
        }
        if (this.arrayValidators) {
            this.arrayValidators.forEach(function (i) {
                i.setValidationContext(_this.validationContext);
                i.setInnerValidation(_this.innerValidationError);
            });
        }
        if (this.directives) {
            this.directives.forEach(function (i) {
                i.setValidationContext(_this.validationContext);
                i.setInnerValidation(_this.innerValidationError);
            });
        }
    };
    ValidationContextComponent.prototype.clear = function () {
        if (this.fieldValidators) {
            this.fieldValidators.forEach(function (v) {
                v.clear();
            });
        }
        if (this.arrayValidators) {
            this.arrayValidators.forEach(function (v) {
                v.clear();
            });
        }
        if (this.directives) {
            this.directives.forEach(function (v) {
                v.clear();
            });
        }
        this.cdRef.markForCheck();
    };
    ValidationContextComponent.ctorParameters = function () { return [
        { type: ChangeDetectorRef }
    ]; };
    __decorate([
        ContentChildren(FormFieldContainerComponent, { descendants: true })
    ], ValidationContextComponent.prototype, "fieldValidators", void 0);
    __decorate([
        ContentChildren(FormArrayContainerComponent, { descendants: true })
    ], ValidationContextComponent.prototype, "arrayValidators", void 0);
    __decorate([
        ContentChildren(FormFieldEmptyContainerDirective, { descendants: true })
    ], ValidationContextComponent.prototype, "directives", void 0);
    __decorate([
        Input()
    ], ValidationContextComponent.prototype, "validationContext", void 0);
    __decorate([
        Input()
    ], ValidationContextComponent.prototype, "innerValidationError", void 0);
    ValidationContextComponent = __decorate([
        Component({
            // tslint:disable:component-selector
            selector: '[validationContext]',
            template: '<ng-content></ng-content>'
        })
    ], ValidationContextComponent);
    return ValidationContextComponent;
}());

var InnerMapToMessagePipe = /** @class */ (function () {
    function InnerMapToMessagePipe() {
    }
    InnerMapToMessagePipe.prototype.transform = function (value, args) {
        return value;
    };
    InnerMapToMessagePipe = __decorate([
        Injectable(),
        Pipe({
            name: 'innerMapToMessage',
            pure: false
        })
    ], InnerMapToMessagePipe);
    return InnerMapToMessagePipe;
}());

var MapToMessagePipe = /** @class */ (function () {
    function MapToMessagePipe(cdRef, pipeFactory) {
        this.pipeFactory = pipeFactory;
        if (pipeFactory) {
            try {
                this.pipe = pipeFactory(cdRef);
            }
            catch (e) {
                console.error(e);
                this.pipe = new InnerMapToMessagePipe();
            }
        }
        else {
            this.pipe = new InnerMapToMessagePipe();
        }
    }
    MapToMessagePipe.prototype.transform = function (value) {
        var _a;
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        return (_a = this.pipe).transform.apply(_a, __spread([value], args));
    };
    MapToMessagePipe.ctorParameters = function () { return [
        { type: ChangeDetectorRef, decorators: [{ type: Optional }] },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGES_PIPE_FACTORY_TOKEN,] }] }
    ]; };
    MapToMessagePipe = __decorate([
        Pipe({
            name: 'mapToMessage',
            pure: false
        }),
        __param(0, Optional()),
        __param(1, Optional()), __param(1, Inject(MESSAGES_PIPE_FACTORY_TOKEN))
    ], MapToMessagePipe);
    return MapToMessagePipe;
}());

var defaultConfig = {
    defaultContext: 'GENERAL',
    errorComponent: InputErrorsComponent
};
function configFactory(customConfig, currentConfig) {
    var actualConfig = __assign({}, currentConfig);
    if (customConfig) {
        if (customConfig.defaultContext) {
            actualConfig.defaultContext = customConfig.defaultContext;
        }
        if (customConfig.errorComponent) {
            actualConfig.errorComponent = customConfig.errorComponent;
        }
    }
    return actualConfig;
}
var NgxValidationErrorsModule = /** @class */ (function () {
    function NgxValidationErrorsModule() {
    }
    NgxValidationErrorsModule_1 = NgxValidationErrorsModule;
    NgxValidationErrorsModule.forRoot = function (config) {
        return {
            ngModule: NgxValidationErrorsModule_1,
            providers: [
                {
                    provide: ValidationErrorsConfigObject, useValue: defaultConfig
                },
                {
                    provide: FOR_ROOT_OPTIONS_TOKEN,
                    useValue: config
                },
                MapToMessagePipe,
                {
                    provide: VALIDATION_ERROR_CONFIG,
                    useFactory: configFactory,
                    deps: [FOR_ROOT_OPTIONS_TOKEN, ValidationErrorsConfigObject]
                },
                MapToMessagePipe,
                InnerMapToMessagePipe
            ]
        };
    };
    var NgxValidationErrorsModule_1;
    NgxValidationErrorsModule = NgxValidationErrorsModule_1 = __decorate([
        NgModule({
            declarations: [
                InputErrorsComponent,
                FormFieldContainerComponent,
                FormFieldEmptyContainerDirective,
                FormArrayContainerComponent,
                ValidationContextComponent,
                MapToMessagePipe,
                InnerMapToMessagePipe
            ],
            imports: [
                CommonModule,
                FormsModule,
                ReactiveFormsModule
            ],
            exports: [
                InputErrorsComponent,
                FormFieldContainerComponent,
                FormArrayContainerComponent,
                ValidationContextComponent,
                FormFieldEmptyContainerDirective
            ],
            entryComponents: [
                InputErrorsComponent
            ]
        })
    ], NgxValidationErrorsModule);
    return NgxValidationErrorsModule;
}());

/**
 * Generated bundle index. Do not edit.
 */

export { ForFieldErrorsContext, FormArrayContainerComponent, FormFieldContainerComponent, FormFieldEmptyContainerDirective, InputErrorsComponent, MESSAGES_PIPE_FACTORY_TOKEN, MESSAGES_PROVIDER, NgxValidationErrorsModule, ValidationContextComponent, defaultConfig as ɵa, configFactory as ɵb, ValidationErrorsConfigObject as ɵc, FOR_ROOT_OPTIONS_TOKEN as ɵd, FormValidationContainer as ɵe, VALIDATION_ERROR_CONFIG as ɵg, MapToMessagePipe as ɵh, InnerMapToMessagePipe as ɵi };
//# sourceMappingURL=xtream-ngx-validation-errors.js.map
